@@ -15,17 +15,18 @@ from .common.compat import iteritems, text_type
 __all__ = (
     "__name__", "__version__", "__author__", "__email__", "__license__", "__summary__", "__url__",
     "CONDA_PACKAGE_ROOT", "CondaError", "CondaMultiError", "CondaExitZero", "conda_signal_handler",
+    "__copyright__",
 )
 
 __name__ = "conda"
-__version__ = "4.3.24"
-__author__ = "Continuum Analytics, Inc."
+__version__ = "4.3.27"
+__author__ = "Anaconda, Inc."
 __email__ = "conda@continuum.io"
-__license__ = "BSD"
+__license__ = "BSD-3-Clause"
+__copyright__ = "Copyright (c) 2012, Anaconda, Inc."
 __summary__ = __doc__
 __url__ = "https://github.com/conda/conda"
 
-
 if os.getenv('CONDA_ROOT') is None:
     os.environ[str('CONDA_ROOT')] = sys.prefix
 
