@@ -72,7 +72,7 @@ def ssl_verify_validation(value):
 class Context(Configuration):
 
     add_pip_as_python_dependency = PrimitiveParameter(True)
-    allow_softlinks = PrimitiveParameter(True)
+    allow_softlinks = PrimitiveParameter(False)
     auto_update_conda = PrimitiveParameter(True, aliases=('self_update',))
     clobber = PrimitiveParameter(False)
     changeps1 = PrimitiveParameter(True)
@@ -82,6 +82,7 @@ class Context(Configuration):
                                         element_type=string_types + (NoneType,))
     disallow = SequenceParameter(string_types)
     force_32bit = PrimitiveParameter(False)
+    non_admin_enabled = PrimitiveParameter(True)
     path_conflict = PrimitiveParameter(PathConflict.clobber)
     pinned_packages = SequenceParameter(string_types, string_delimiter='/')  # TODO: consider a different string delimiter  # NOQA
     rollback_enabled = PrimitiveParameter(True)
@@ -531,7 +532,10 @@ def get_help_dict():
         'always_softlink': dals("""
             Register a preference that files be soft-linked (symlinked) into a prefix during
             install rather than hard-linked. The link source is the 'pkgs_dir' package cache
-            from where the package is being linked.
+            from where the package is being linked. WARNING: Using this option can result in
+            corruption of long-lived conda environments. Package caches are *caches*, which
+            means there is some churn and invalidation. With this option, the contents of
+            environments can be switched out (or erased) via operations on other environments.
             """),
         'always_yes': dals("""
             Automatically choose the 'yes' option whenever asked to proceed with a conda
@@ -622,6 +626,10 @@ def get_help_dict():
             A list of previously-used channel_alias values, useful for example when switching
             between different Anaconda Repository instances.
             """),
+        'non_admin_enabled': dals("""
+            Allows completion of conda's create, install, update, and remove operations, for
+            non-privileged (non-root or non-administrator) users.
+            """),
         'offline': dals("""
             Restrict conda to cached download content and file:// based urls.
             """),
