@@ -3,6 +3,7 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 
 import bz2
 from contextlib import closing
+from errno import ENODEV
 from functools import wraps
 from genericpath import getmtime, isfile
 import hashlib
@@ -53,8 +54,8 @@ log = getLogger(__name__)
 dotlog = getLogger('dotupdate')
 stderrlog = getLogger('stderrlog')
 
-REPODATA_PICKLE_VERSION = 1
-REPODATA_HEADER_RE = b'"(_etag|_mod|_cache_control)":[ ]?"(.*)"'
+REPODATA_PICKLE_VERSION = 2
+REPODATA_HEADER_RE = b'"(_etag|_mod|_cache_control)":[ ]?"(.*?[^\\\\])"[,\}\s]'
 
 
 def collect_all_repodata(use_cache, tasks):
@@ -82,11 +83,16 @@ def read_mod_and_etag(path):
                 match_objects = take(3, re.finditer(REPODATA_HEADER_RE, m))
                 result = dict(map(ensure_unicode, mo.groups()) for mo in match_objects)
                 return result
-        except (BufferError, ValueError):
+        except (BufferError, ValueError, OSError):  # pragma: no cover
             # BufferError: cannot close exported pointers exist
             #   https://github.com/conda/conda/issues/4592
             # ValueError: cannot mmap an empty file
             return {}
+        except (IOError, OSError) as e:  # pragma: no cover
+            # OSError: [Errno 19] No such device
+            if e.errno == ENODEV:
+                return {}
+            raise
 
 
 def get_cache_control_max_age(cache_control_value):
@@ -490,6 +496,24 @@ def _collect_repodatas_concurrent(executor, use_cache, tasks):
     return repodatas
 
 
+def make_feature_record(feature_name, feature_value):
+    # necessary for the SAT solver to do the right thing with features
+    pkg_name = "%s=%s@" % (feature_name, feature_value)
+    return IndexRecord(
+        name=pkg_name,
+        version='0',
+        build='0',
+        channel='@',
+        subdir=context.subdir,
+        md5="12345678901234567890123456789012",
+        provides_features={
+            feature_name: feature_value,
+        },
+        build_number=0,
+        fn=pkg_name,
+    )
+
+
 def cache_fn_url(url):
     # url must be right-padded with '/' to not invalidate any existing caches
     if not url.endswith('/'):
